pub fn lune_classify(
a: &SphericalPoint,
b: &SphericalPoint,
point: &SphericalPoint,
) -> LuneSideExpand description
Determines which side of the angular bisector plane between a and b
a point lies on.
The bisector plane is defined by the great circle equidistant from a
and b. Points on A’s side are angularly closer to A than to B.